Index: src/crankshaft/arm64/lithium-codegen-arm64.cc |
diff --git a/src/crankshaft/arm64/lithium-codegen-arm64.cc b/src/crankshaft/arm64/lithium-codegen-arm64.cc |
index 0a59c8db4337a5fa7d135c077d4fdd6f66b7d91c..4d8e6615e7c16c76ec90f5c301f654aa5b683cda 100644 |
--- a/src/crankshaft/arm64/lithium-codegen-arm64.cc |
+++ b/src/crankshaft/arm64/lithium-codegen-arm64.cc |
@@ -3240,11 +3240,11 @@ void LCodeGen::DoLoadKeyedFixed(LLoadKeyedFixed* instr) { |
__ B(ne, &done); |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
// it needs to bail out. |
__ LoadRoot(result, Heap::kArrayProtectorRootIndex); |
__ Ldr(result, FieldMemOperand(result, Cell::kValueOffset)); |
- __ Cmp(result, Operand(Smi::FromInt(Isolate::kArrayProtectorValid))); |
+ __ Cmp(result, Operand(Smi::FromInt(Isolate::kProtectorValid))); |
DeoptimizeIf(ne, instr, DeoptimizeReason::kHole); |
} |
__ LoadRoot(result, Heap::kUndefinedValueRootIndex); |
@@ -3240,11 +3240,11 @@ void LCodeGen::DoLoadKeyedFixed(LLoadKeyedFixed* instr) { |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
+ // protector cell contains (Smi) Isolate::kProtectorValid. Otherwise |
// it needs to bail out. |
__ LoadRoot(result, Heap::kArrayProtectorRootIndex); |